/*
 * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * $Id: JSONBPropertyManager.java 74780 2017-01-16 18:03:04Z psplinak $
 */
 

package com.sun.ts.lib.deliverable.jsonb;

import java.util.Properties;

import com.sun.javatest.TestEnvironment;
import com.sun.ts.lib.deliverable.AbstractPropertyManager;
import com.sun.ts.lib.deliverable.PropertyNotSetException;


/**
 * This class serves as a well known place for harness, util, and porting
 * classes to retrieve property values.
 */
public class JSONBPropertyManager extends AbstractPropertyManager {
    private static JSONBPropertyManager jteMgr = new JSONBPropertyManager();

    /**
     * This method returns
     * the singleton instance of JSONBPropertyManager which provides access
     * to all ts.jte properties.  This is only called once by the test harness.
     *
     * @param	env - TestEnvironment object from JavaTest
     * @return	JSONBPropertyManager - singleton property manager object
     */
    public final static JSONBPropertyManager getJSONBPropertyManager (TestEnvironment env) throws Exception {
        jteMgr.setTestEnvironment(env);
        return  jteMgr;
    }

    /**
     * This method returns
     * the singleton instance of JSONBPropertyManager which provides access
     * to all ts.jte properties.  This is only called by the init()
     * method in ManualDeployment.java
     *
     * @param	p - Properties object from JavaTest
     * @return	JSONBPropertyManager - singleton property manager object
     */
    public final static JSONBPropertyManager getJSONBPropertyManager (Properties p) throws Exception {
        jteMgr.setJteProperties(p);
        return  jteMgr;
    }

    public final static JSONBPropertyManager getJSONBPropertyManager () throws Exception {
        return  jteMgr;
    }

    /**
     * This method is called by the test harness to retrieve all properties
     * needed by a particular test.
     *
     * @param	sPropKeys - Properties to retrieve
     * @return	Properties - property/value pairs
     */
    public Properties getTestSpecificProperties (String[] sPropKeys) throws PropertyNotSetException {
        Properties pTestProps = super.getTestSpecificProperties(sPropKeys);
        pTestProps.put("porting.ts.url.class.1", getProperty("porting.ts.url.class.1"));
        String tsHome = getProperty("TS_HOME", null);
        if(tsHome == null)
            tsHome = getProperty("cts_home", null);
        if(tsHome != null)
                pTestProps.put("cts_home", tsHome);

        return  pTestProps;
    }
}



